#!/usr/bin/python

from ansible.module_utils.basic import *
from shutil import copyfile
import glob


def main():
    module = AnsibleModule(argument_spec=dict(
        src=dict(type='str', required=True),
        dest=dict(type='str', required=True),
        remove_from_dest=dict(type='str', required=True)
    ))

    changed = False

    previousfile = module.params["dest"] + "/" + module.params["remove_from_dest"]
    for file in glob.glob(previousfile):
        changed = True
        os.remove(file)

    for file in glob.glob(module.params["src"]):
        changed = True
        copyfile(file, module.params["dest"])

    module.exit_json(changed=changed)


if __name__ == '__main__':
    main()



#!/usr/bin/python

from ansible.module_utils.basic import *
from shutil import copyfile
import glob


def main():
    module = AnsibleModule(argument_spec=dict(
        src=dict(type='str', required=True),
        dest=dict(type='str', required=True)
    ))

    # Ensure backup dir exists
    if not os.path.isdir(module.params["dest"]):
        os.makedirs(module.params["dest"])

    changed = False
    for file in glob.glob(module.params["src"]):
        changed = True
        copyfile(file, module.params["dest"] + "/" + os.path.basename(file))

    module.exit_json(changed=changed)


if __name__ == '__main__':
    main()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from pathlib import Path
import os

ALLO_INFO_PATH = '/tmp/allo-infos.yml'

CONFIG_PATH = "/etc/allo-config.dict"

ALLO_URL = "10.81.41.1:3025" \
    if os.getenv("ALLOENV") == "TEST" \
    else "allo.dev.libriciel.fr:443"

API_PATH = "https://{}/v1/webapi".format("10.81.41.1:3080") \
    if os.getenv("ALLOENV") == "TEST" \
    else "https://{}/api/client".format(ALLO_URL)

CODEPRODUIT = {
    "i-Parapheur": "IP",
    "Pastell": "PA"
}



# -*- coding: utf-8 -*-
import pickle
import os

from allo.model.version import Version
from allo.const import CONFIG_PATH


class AlloConfig:
    id: int
    id_client: str
    code_produit: str
    teleport_token: str
    env: str
    repo_path: str
    version: Version
    internal: bool = False

    @staticmethod
    def load():
        if os.path.exists(CONFIG_PATH):
            with open(CONFIG_PATH, 'rb') as config_dictionary_file:
                return pickle.load(config_dictionary_file)
        else:
            return AlloConfig()

    def save(self):
        with open(CONFIG_PATH, 'wb') as config_dictionary_file:
            pickle.dump(self, config_dictionary_file)



#!/usr/bin/python

from ansible.module_utils.basic import *


def main():
    module = AnsibleModule(argument_spec=dict(
        state=dict(type='str', required=True)
    ))
    with open("/tmp/progress.log", "a") as file_object:
        # Append 'hello' at the end of file
        file_object.write(module.params["state"] + "\n")
    module.exit_json(changed=True)


if __name__ == '__main__':
    main()
